netapp_ontap.models.rfc2307_attribute API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.rfc2307_attribute`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class Rfc2307AttributeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Rfc2307Attribute object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `gecos: str GET POST PATCH`

    RFC 2307 gecos attribute.

    Example: name

  `gid_number: str GET POST PATCH`

    RFC 2307 gidNumber attribute.

    Example: msSFU30GidNumber

  `home_directory: str GET POST PATCH`

    RFC 2307 homeDirectory attribute.

    Example: msSFU30HomeDirectory

  `login_shell: str GET POST PATCH`

    RFC 2307 loginShell attribute.

    Example: msSFU30LoginShell

  `uid: str GET POST PATCH`

    RFC 1274 userid attribute used by RFC 2307 as UID.

    Example: sAMAccountName

  `uid_number: str GET POST PATCH`

    RFC 2307 uidNumber attribute.

    Example: msSFU30UidNumber

  `user_password: str GET POST PATCH`

    RFC 2256 userPassword attribute used by RFC 2307.

    Example: msSFU30Password